@@ -11,6 +11,8 @@ from .dsp import (
     time_shift,
     time_window,
     kaiser_window_beta,
+    deconvolve,
+    convolve,
     InterpolateSpectrum,
 )
 
@@ -33,5 +35,7 @@ __all__ = [
     'time_shift',
     'time_window',
     'kaiser_window_beta',
+    'deconvolve',
+    'convolve',
     'InterpolateSpectrum',
 ]
