@@ -180,7 +180,7 @@ def _group_delay_2d(signal, unit, freq_scale, indices, orientation, cmap,
 
     # check input and prepare the figure, axis, and common parameters
     fig, ax, indices, kwargs = _utils._prepare_2d_plot(
-        signal, (Signal), 2, indices, ax, colorbar, **kwargs)
+        signal, (Signal, ), 2, indices, ax, colorbar, **kwargs)
     _utils._check_axis_scale(freq_scale)
 
     # prepare input
@@ -305,7 +305,7 @@ def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
     # check input
     # check input and prepare the figure and axis
     fig, ax, _, kwargs = _utils._prepare_2d_plot(
-        signal, (Signal), 1, None, ax, colorbar, **kwargs)
+        signal, (Signal, ), 1, None, ax, colorbar, **kwargs)
     _utils._check_time_unit(unit)
     _utils._check_axis_scale(freq_scale, 'y')
 
