@@ -141,8 +141,8 @@ def linear_sweep(n_samples, frequency_range, n_fade_out=90, amplitude=1,
                    "of pyfar.signals.linear_sweep_time."),
                   PendingDeprecationWarning)
 
-    linear_sweep_time(n_samples, frequency_range, n_fade_out, amplitude,
-                      sampling_rate)
+    return linear_sweep_time(
+        n_samples, frequency_range, n_fade_out, amplitude, sampling_rate)
 
 
 def linear_sweep_time(n_samples, frequency_range, n_fade_out=90, amplitude=1,
@@ -208,8 +208,9 @@ def exponential_sweep(n_samples, frequency_range, n_fade_out=90,
                    "of pyfar.signals.exponential_sweep_time."),
                   PendingDeprecationWarning)
 
-    exponential_sweep_time(n_samples, frequency_range, n_fade_out,
-                           amplitude, sweep_rate, sampling_rate)
+    return exponential_sweep_time(
+        n_samples, frequency_range, n_fade_out,
+        amplitude, sweep_rate, sampling_rate)
 
 
 def exponential_sweep_time(n_samples, frequency_range, n_fade_out=90,
